// Copyright (c) 2011, Chute Corporation. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
//
// * Redistributions of source code must retain the above copyright notice, this
// list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright notice,
// this list of conditions and the following disclaimer in the documentation
// and/or other materials provided with the distribution.
// * Neither the name of the Chute Corporation nor the names
// of its contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
// INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
// BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
// OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
// OF THE POSSIBILITY OF SUCH DAMAGE.
//
package darko.imagedownloader;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.net.Uri;

import com.araneaapps.android.libs.logger.ALog;


/**
 * @author Darko.Grozdanovski
 **/
public class Utils {

    private static final String TAG = Utils.class.getSimpleName();

    public static void copyStream(InputStream is, OutputStream os) {
	final int buffer_size = 1024;
	try {
	    byte[] bytes = new byte[buffer_size];
	    for (;;) {
		int count = is.read(bytes, 0, buffer_size);
		if (count == -1) {
		    break;
		}
		os.write(bytes, 0, count);
	    }
	} catch (Exception ex) {
	    ex.printStackTrace();
	}
    }

    public static String getProtocol(String url) {
	Uri uri = Uri.parse(url);
	return uri.getScheme();
    }

    public static BitmapFactory.Options decodeInBounds(File file, int size) throws IOException {
	BitmapFactory.Options o = new BitmapFactory.Options();
	o.inJustDecodeBounds = true;
	BitmapFactory.Options o2;
	try {
	    BitmapFactory.decodeFile(file.getPath(), o);
	    int width_tmp = o.outWidth, height_tmp = o.outHeight;
	    int scale = 1;
	    while (true) {
		if (width_tmp / 2 < size || height_tmp / 2 < size) {
		    break;
		}
		width_tmp /= 2;
		height_tmp /= 2;
		scale *= 2;
	    }
	    o2 = new BitmapFactory.Options();
	    o2.inSampleSize = scale;
	} finally {
	}
	return o2;
    }

    public static final Bitmap getThumbnailFromFilename(String path) {
	Options decodeInBounds;
	try {
	    decodeInBounds = Utils.decodeInBounds(new File(path), 75);
	    return BitmapFactory.decodeFile(path, decodeInBounds);
	} catch (IOException e) {
	    ALog.d(TAG, "", e);
	}
	return null;
    }
}
